@@ -10,7 +10,7 @@ SSH_CLIENT_FOLDER = os.path.join(HOME, ".ssh")
 SSH_CONFIG_PATH = os.path.join(HOME, ".ssh", "config")
 
 red = lambda text: f"\033[31m{text}\033[0m"
-yellow = lambda text: f"\033[33;1m{text}\033[0m"
+yellow = lambda text: f"\033[33m{text}\033[0m"
 cyan = lambda text: f"\033[36;1m{text}\033[0m"
 
 if not os.path.exists(SSH_CLIENT_FOLDER):
@@ -87,7 +87,7 @@ def main():
     with open(SSH_CONFIG_PATH, "w") as fp:
 
         for machine_name in name_generator():
-            print("\n=== " + yellow(f"um-ad\\{user_sso}@{machine_name}.managed.mst.edu") + " ===")
+            print("\n=== " + yellow(f"um-ad\{user_sso}@{machine_name}.managed.mst.edu") + " ===")
             identity_file = os.path.join(SSH_CLIENT_FOLDER, machine_name)
             if os.path.exists(identity_file):
                 os.remove(identity_file)
